==> pygame-2.0.0.tar.gz: pygame-2.0.0/src_c/doc/mouse_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in docs/reST/ref/ . */
#define DOC_PYGAMEMOUSE "pygame module to work with the mouse"
#define DOC_PYGAMEMOUSEGETPRESSED "get_pressed(num_buttons=3) -> (button1, button2, button3)\nget_pressed(num_buttons=5) -> (button1, button2, button3, button4, button5)\nget the state of the mouse buttons"
#define DOC_PYGAMEMOUSEGETPOS "get_pos() -> (x, y)\nget the mouse cursor position"
#define DOC_PYGAMEMOUSEGETREL "get_rel() -> (x, y)\nget the amount of mouse movement"
#define DOC_PYGAMEMOUSESETPOS "set_pos([x, y]) -> None\nset the mouse cursor position"
#define DOC_PYGAMEMOUSESETVISIBLE "set_visible(bool) -> bool\nhide or show the mouse cursor"
#define DOC_PYGAMEMOUSEGETVISIBLE "get_visible() -> bool\nget the current visibility state of the mouse cursor"
#define DOC_PYGAMEMOUSEGETFOCUSED "get_focused() -> bool\ncheck if the display is receiving mouse input"
#define DOC_PYGAMEMOUSESETCURSOR "set_cursor(size, hotspot, xormasks, andmasks) -> None\nset the image for the mouse cursor"
#define DOC_PYGAMEMOUSESETSYSTEMCURSOR "set_system_cursor(constant) -> None\nset the mouse cursor to a system variant"
#define DOC_PYGAMEMOUSEGETCURSOR "get_cursor() -> (size, hotspot, xormasks, andmasks)\nget the image of the mouse cursor"


/* Docs in a comment... slightly easier to read. */

/*

pygame.mouse
pygame module to work with the mouse

pygame.mouse.get_pressed
 get_pressed(num_buttons=3) -> (button1, button2, button3)
 get_pressed(num_buttons=5) -> (button1, button2, button3, button4, button5)
get the state of the mouse buttons

pygame.mouse.get_pos
 get_pos() -> (x, y)
get the mouse cursor position

pygame.mouse.get_rel
 get_rel() -> (x, y)
get the amount of mouse movement

pygame.mouse.set_pos
 set_pos([x, y]) -> None
set the mouse cursor position

pygame.mouse.set_visible
 set_visible(bool) -> bool
hide or show the mouse cursor

pygame.mouse.get_visible
 get_visible() -> bool
get the current visibility state of the mouse cursor

pygame.mouse.get_focused
 get_focused() -> bool
check if the display is receiving mouse input

pygame.mouse.set_cursor
 set_cursor(size, hotspot, xormasks, andmasks) -> None
set the image for the mouse cursor

pygame.mouse.set_system_cursor
 set_system_cursor(constant) -> None
set the mouse cursor to a system variant

pygame.mouse.get_cursor
 get_cursor() -> (size, hotspot, xormasks, andmasks)
get the image of the mouse cursor

*/

==> pygame_2.6.1.orig.tar.gz: pygame-2.6.1/src_c/doc/mouse_doc.h <==
/* Auto generated file: with makeref.py .  Docs go in docs/reST/ref/ . */
#define DOC_PYGAMEMOUSE "pygame module to work with the mouse"
#define DOC_PYGAMEMOUSEGETPRESSED "get_pressed(num_buttons=3) -> (button1, button2, button3)\nget_pressed(num_buttons=5) -> (button1, button2, button3, button4, button5)\nget the state of the mouse buttons"
#define DOC_PYGAMEMOUSEGETPOS "get_pos() -> (x, y)\nget the mouse cursor position"
#define DOC_PYGAMEMOUSEGETREL "get_rel() -> (x, y)\nget the amount of mouse movement"
#define DOC_PYGAMEMOUSESETPOS "set_pos([x, y]) -> None\nset the mouse cursor position"
#define DOC_PYGAMEMOUSESETVISIBLE "set_visible(bool) -> bool\nhide or show the mouse cursor"
#define DOC_PYGAMEMOUSEGETVISIBLE "get_visible() -> bool\nget the current visibility state of the mouse cursor"
#define DOC_PYGAMEMOUSEGETFOCUSED "get_focused() -> bool\ncheck if the display is receiving mouse input"
#define DOC_PYGAMEMOUSESETCURSOR "set_cursor(pygame.cursors.Cursor) -> None\nset_cursor(size, hotspot, xormasks, andmasks) -> None\nset_cursor(hotspot, surface) -> None\nset_cursor(constant) -> None\nset the mouse cursor to a new cursor"
#define DOC_PYGAMEMOUSEGETCURSOR "get_cursor() -> pygame.cursors.Cursor\nget the current mouse cursor"


/* Docs in a comment... slightly easier to read. */

/*

pygame.mouse
pygame module to work with the mouse

pygame.mouse.get_pressed
 get_pressed(num_buttons=3) -> (button1, button2, button3)
 get_pressed(num_buttons=5) -> (button1, button2, button3, button4, button5)
get the state of the mouse buttons

pygame.mouse.get_pos
 get_pos() -> (x, y)
get the mouse cursor position

pygame.mouse.get_rel
 get_rel() -> (x, y)
get the amount of mouse movement

pygame.mouse.set_pos
 set_pos([x, y]) -> None
set the mouse cursor position

pygame.mouse.set_visible
 set_visible(bool) -> bool
hide or show the mouse cursor

pygame.mouse.get_visible
 get_visible() -> bool
get the current visibility state of the mouse cursor

pygame.mouse.get_focused
 get_focused() -> bool
check if the display is receiving mouse input

pygame.mouse.set_cursor
 set_cursor(pygame.cursors.Cursor) -> None
 set_cursor(size, hotspot, xormasks, andmasks) -> None
 set_cursor(hotspot, surface) -> None
 set_cursor(constant) -> None
set the mouse cursor to a new cursor

pygame.mouse.get_cursor
 get_cursor() -> pygame.cursors.Cursor
get the current mouse cursor

*/
